==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebAccordionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebAccordionDescription } from "./WebAccordionDescription";
/**
 * @hidden
 */
var WebAccordionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebAccordionDescriptionMetadata, _super);
    function WebAccordionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebAccordionDescriptionMetadata.b = function (a) {
        if (WebAccordionDescriptionMetadata.a == null) {
            WebAccordionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebAccordionDescriptionMetadata.c(WebAccordionDescriptionMetadata.a);
        }
        if (a.k(WebAccordionDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebAccordionDescriptionMetadata.a);
    };
    WebAccordionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Accordion");
        a.item("__tagNameWC", "String:igc-accordion");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("SingleExpand", "Boolean");
    };
    WebAccordionDescriptionMetadata.d = function (a) {
        WebAccordionDescriptionMetadata.b(a);
        a.ac("WebAccordion", function () { return new WebAccordionDescription(); });
        a.ab("WebAccordion", WebAccordionDescriptionMetadata.a);
    };
    WebAccordionDescriptionMetadata.$t = markType(WebAccordionDescriptionMetadata, 'WebAccordionDescriptionMetadata');
    WebAccordionDescriptionMetadata.a = null;
    return WebAccordionDescriptionMetadata;
}(Base));
export { WebAccordionDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebAccordionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExpansionPanelComponentEventArgsDescriptionMetadata } from "./WebExpansionPanelComponentEventArgsDescriptionMetadata";
import { WebAccordionDescription } from "./WebAccordionDescription";
/**
 * @hidden
 */
var WebAccordionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebAccordionDescriptionMetadata, _super);
    function WebAccordionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebAccordionDescriptionMetadata.b = function (a) {
        if (WebAccordionDescriptionMetadata.a == null) {
            WebAccordionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebAccordionDescriptionMetadata.c(WebAccordionDescriptionMetadata.a);
        }
        if (a.k(WebAccordionDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebAccordionDescriptionMetadata.a);
        WebExpansionPanelComponentEventArgsDescriptionMetadata.d(a);
    };
    WebAccordionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Accordion");
        a.item("__tagNameWC", "String:igc-accordion");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("SingleExpand", "Boolean");
        a.item("OpeningRef", "EventRef::opening");
        a.item("OpenedRef", "EventRef::opened");
        a.item("ClosingRef", "EventRef::closing");
        a.item("ClosedRef", "EventRef::closed");
    };
    WebAccordionDescriptionMetadata.d = function (a) {
        WebAccordionDescriptionMetadata.b(a);
        a.ae("WebAccordion", function () { return new WebAccordionDescription(); });
        a.ad("WebAccordion", WebAccordionDescriptionMetadata.a);
    };
    WebAccordionDescriptionMetadata.$t = markType(WebAccordionDescriptionMetadata, 'WebAccordionDescriptionMetadata');
    WebAccordionDescriptionMetadata.a = null;
    return WebAccordionDescriptionMetadata;
}(Base));
export { WebAccordionDescriptionMetadata };
